@@ -51,6 +51,15 @@ public class MainWindow {
 	[Glade.Widget] MenuItem update_thumbnail;
 	[Glade.Widget] MenuItem delete_from_drive;
 
+	[Glade.Widget] MenuItem send_mail;
+	[Glade.Widget] MenuItem export;
+	[Glade.Widget] MenuItem print;
+	[Glade.Widget] MenuItem select_none;
+	[Glade.Widget] MenuItem adjust_color;
+	[Glade.Widget] MenuItem exif_data;
+	[Glade.Widget] MenuItem sharpen;
+	[Glade.Widget] MenuItem remove_from_catalog;
+
 	[Glade.Widget] MenuItem display_tags_menu_item;
 
 	[Glade.Widget] MenuItem set_as_background;
@@ -59,6 +68,8 @@ public class MainWindow {
 	[Glade.Widget] MenuItem remove_tag;
 	[Glade.Widget] MenuItem find_tag;
 
+	[Glade.Widget] VPaned info_vpaned;
+
 	PhotoVersionMenu versions_submenu;
 
 	Gtk.ToggleButton browse_button;
@@ -115,7 +126,7 @@ public class MainWindow {
 		this.db = db;
 
 		Mono.Posix.Catalog.Init ("f-spot", FSpot.Defines.LOCALE_DIR);
-		Glade.XML gui = Glade.XML.FromAssembly ("f-spot.glade", "main_window", null);
+		Glade.XML gui = Glade.XML.FromAssembly ("f-spot.glade", "main_window", "");
 		gui.Autoconnect (this);
 
 		slide_delay = new FSpot.Delay (new GLib.IdleHandler (SlideShow));
@@ -417,9 +428,13 @@ public class MainWindow {
 			if (t.Icon == null) {
 				if (icon == null) {
 					// FIXME this needs a lot more work.
-					Pixbuf tmp = PixbufUtils.LoadAtMaxSize (query.Photos[num].DefaultVersionPath, 128, 128);
-					icon = PixbufUtils.TagIconFromPixbuf (tmp);
-					tmp.Dispose ();
+					try {
+						Pixbuf tmp = PixbufUtils.LoadAtMaxSize (query.Photos[num].DefaultVersionPath, 128, 128);
+						icon = PixbufUtils.TagIconFromPixbuf (tmp);
+						tmp.Dispose ();
+					} catch {
+						icon = null;
+					}
 				}
 				
 				t.Icon = icon;
@@ -565,9 +580,13 @@ public class MainWindow {
 
 			bool use_icon = false;;
 			while (len-- > 0) {
-				string thumbnail_path = Thumbnail.PathForUri (photos[len].DefaultVersionUri.ToString (), 
-									      ThumbnailSize.Large);
-				Pixbuf thumbnail = ThumbnailCache.Default.GetThumbnailForPath (thumbnail_path);
+				string thumbnail_path = FSpot.ThumbnailGenerator.ThumbnailPath (photos [len].DefaultVersionUri);
+				FSpot.PixbufCache.CacheEntry entry = icon_view.Cache.Lookup (thumbnail_path);
+
+				Pixbuf thumbnail = null;
+				if (entry != null)
+					thumbnail = entry.ShallowCopyPixbuf ();
+				
 				if (thumbnail != null) {
 					Pixbuf small = PixbufUtils.ScaleToMaxSize (thumbnail, size, size);				
 
@@ -909,7 +928,7 @@ public class MainWindow {
 
 	void HandleExportToOriginal (object sender, EventArgs args)
 	{
-		new FSpot.OriginalExport (new FSpot.PhotoArray (SelectedPhotos ()));
+		new FSpot.FolderExport (new FSpot.PhotoArray (SelectedPhotos ()));
 	}
 
 	void HandleViewDirectory (object sender, EventArgs args)
@@ -959,6 +978,7 @@ public class MainWindow {
 		string [] authors = new string [] {
 			"Ettore Perazzoli",
 			"Lawrence Ewing",
+			"Laurence Hygate",
 			"Nat Friedman",
 			"Miguel de Icaza",
 			"Vladimir Vukicevic",
@@ -973,9 +993,7 @@ public class MainWindow {
 			"Ewen Cheslack-Postava",
 			"Patanjali Somayaji",
 			"Matt Jones",
-			"Martin Willemoes Hansen",
-			"Laurence Hygate"
-
+			"Martin Willemoes Hansen"
 		};
 
                 // Translators should localize the following string
@@ -983,7 +1001,7 @@ public class MainWindow {
                 // * E.g. "Martin Willemoes Hansen"
                 string translators = Mono.Posix.Catalog.GetString ("translator-credits");
 
-                new About (FSpot.Defines.PACKAGE, 
+                new About ("F-Spot", 
 			   FSpot.Defines.VERSION, 
 			   "Copyright 2003-2005 Novell Inc.",
                            null, authors, null, translators, null).Show();
@@ -1125,8 +1143,8 @@ public class MainWindow {
 		table.Attach (new Gtk.Label (Mono.Posix.Catalog.GetString ("Radius:")), 0, 1, 1, 2);
 		table.Attach (new Gtk.Label (Mono.Posix.Catalog.GetString ("Threshold:")), 0, 1, 2, 3);
 
-		Gtk.SpinButton amount_spin = new Gtk.SpinButton (0.0, 100.0, .01);
-		Gtk.SpinButton radius_spin = new Gtk.SpinButton (0.0, 50.0, .01);
+		Gtk.SpinButton amount_spin = new Gtk.SpinButton (0.5, 100.0, .01);
+		Gtk.SpinButton radius_spin = new Gtk.SpinButton (5.0, 50.0, .01);
 		Gtk.SpinButton threshold_spin = new Gtk.SpinButton (0.0, 50.0, .01);
 
 		table.Attach (amount_spin, 1, 2, 0, 1);
@@ -1149,10 +1167,12 @@ public class MainWindow {
 			
 				Photo photo = query.Photos [id];
 				Exif.ExifData exif_data = new Exif.ExifData (photo.DefaultVersionPath);
-
+				
+				bool created_version = false;
 				uint version = photo.DefaultVersionId;
 				if (version == Photo.OriginalVersionId) {
 					version = photo.CreateDefaultModifiedVersion (photo.DefaultVersionId, false);
+					created_version = true;
 				}
 				
 				try {
@@ -1162,9 +1182,20 @@ public class MainWindow {
 					FSpot.ThumbnailGenerator.Create (version_path).Dispose ();
 					photo.DefaultVersionId = version;
 					query.Commit (id);
-				} catch (GLib.GException ex) {
-					// FIXME error dialog.
-					Console.WriteLine ("error {0}", ex);
+				} catch (System.Exception e) {
+					string msg = Mono.Posix.Catalog.GetString ("Error saving sharpened photo");
+					string desc = String.Format (Mono.Posix.Catalog.GetString ("Received exception \"{0}\". Unable to save image {1}"),
+								     e.Message, photo.Name);
+					
+					HigMessageDialog md = new HigMessageDialog (main_window, DialogFlags.DestroyWithParent, 
+										    Gtk.MessageType.Error, ButtonsType.Ok, 
+										    msg,
+										    desc);
+					md.Run ();
+					md.Destroy ();
+					
+					if (created_version)
+						photo.DeleteVersion (version);
 				}
 			
 			}
@@ -1206,6 +1237,14 @@ public class MainWindow {
 			group_selector.Show ();
 	}
 
+	void HandleDisplayInfoSidebar (object sender, EventArgs args)
+	{
+		if (info_vpaned.Visible)
+			info_vpaned.Hide ();
+		else
+			info_vpaned.Show ();
+	}
+
 	void HandleViewSlideShow (object sender, EventArgs args)
 	{
 		main_window.GdkWindow.Cursor = new Gdk.Cursor (Gdk.CursorType.Watch);
@@ -1214,7 +1253,6 @@ public class MainWindow {
 
 	private bool SlideShow ()
 	{
-		Gtk.Window win = new Gtk.Window ("test");
 		Pixbuf bg = PixbufUtils.LoadFromScreen ();
 
 		int [] ids = SelectedIds ();
@@ -1232,52 +1270,19 @@ public class MainWindow {
 		} else {
 			photos = SelectedPhotos ();
 		}
-		
+
 		if (photos.Length == 0) {
 			Console.WriteLine ("No photos available -- no slideshow");
 			main_window.GdkWindow.Cursor = null;
 			return false;
 		}
 
-		SlideView slideview = new SlideView (bg, photos);
-		win.ButtonPressEvent += HandleSlideViewButtonPressEvent;
-		win.KeyPressEvent += HandleSlideViewKeyPressEvent;
-		win.AddEvents ((int) (EventMask.ButtonPressMask | EventMask.KeyPressMask));
-		win.Add (slideview);
-		win.Decorated = false;
-		win.Fullscreen();
-		win.Realize ();
-		win.GdkWindow.Cursor = new Gdk.Cursor (Gdk.CursorType.Watch);
-	
-		Gdk.GCValues values = new Gdk.GCValues ();
-		values.SubwindowMode = SubwindowMode.IncludeInferiors;
-		Gdk.GC fillgc = new Gdk.GC (win.GdkWindow, values, Gdk.GCValuesMask.Subwindow);
-
-		slideview.Show ();
-		win.GdkWindow.SetBackPixmap (null, false);
-		win.Show ();
-		main_window.GdkWindow.Cursor = null;	
-		bg.RenderToDrawable (win.GdkWindow, fillgc, 
-				     0, 0, 0, 0, -1, -1, RgbDither.Normal, 0, 0);
-
-		slideview.Play ();
+		FSpot.FullSlide full = new FSpot.FullSlide (bg, photos);
+		full.Play ();
+		main_window.GdkWindow.Cursor = null;
 		return false;
 	}
-	
-	[GLib.ConnectBefore]
-	private void HandleSlideViewKeyPressEvent (object sender, KeyPressEventArgs args)
-	{
-		Gtk.Window win = sender as Gtk.Window;
-		win.Destroy ();
-		args.RetVal = true;
-	}
 
-	private void HandleSlideViewButtonPressEvent (object sender, ButtonPressEventArgs args)
-	{
-		Gtk.Window win = sender as Gtk.Window;
-		win.Destroy ();
-		args.RetVal = true;
-	}
 
 	void HandleToggleViewBrowse (object sender, EventArgs args)
 	{
@@ -1587,7 +1592,11 @@ public class MainWindow {
 
 	void UpdateMenus ()
 	{
-		if (CurrentPhoto == null) {
+		bool tag_sensitive = tag_selection_widget.Selection.CountSelectedRows () > 0;
+		bool active_selection = PhotoSelectionActive ();
+		bool single_active = CurrentPhoto != null;
+		
+		if (!single_active) {
 			version_menu_item.Sensitive = false;
 			version_menu_item.Submenu = new Menu ();
 
@@ -1595,7 +1604,6 @@ public class MainWindow {
 			delete_version_menu_item.Sensitive = false;
 			rename_version_menu_item.Sensitive = false;
 
-			set_as_background.Sensitive = true;
 		} else {
 			version_menu_item.Sensitive = true;
 			create_version_menu_item.Sensitive = true;
@@ -1611,18 +1619,27 @@ public class MainWindow {
 			versions_submenu = new PhotoVersionMenu (CurrentPhoto);
 			versions_submenu.VersionIdChanged += new PhotoVersionMenu.VersionIdChangedHandler (HandleVersionIdChanged);
 			version_menu_item.Submenu = versions_submenu;
-
-			set_as_background.Sensitive = true;
 		}
 
-		bool tag_sensitive = tag_selection_widget.Selection.CountSelectedRows () > 0;
-		bool active_selection = PhotoSelectionActive ();
+		set_as_background.Sensitive = single_active;
+		adjust_color.Sensitive = single_active;
+
+		attach_tag.Sensitive = active_selection;
+		remove_tag.Sensitive = active_selection;
 
 		rotate_left.Sensitive = active_selection;
 		rotate_right.Sensitive = active_selection;
 		update_thumbnail.Sensitive = active_selection;
 		delete_from_drive.Sensitive = active_selection;
 		copy.Sensitive = active_selection;
+		
+		send_mail.Sensitive = active_selection;
+		print.Sensitive = active_selection;
+		export.Sensitive = active_selection;
+		select_none.Sensitive = active_selection;
+		exif_data.Sensitive = active_selection;
+		sharpen.Sensitive = active_selection;
+		remove_from_catalog.Sensitive = active_selection;
 
 		delete_selected_tag.Sensitive = tag_sensitive;
 		edit_selected_tag.Sensitive = tag_sensitive;
