@@ -309,7 +309,7 @@ class PixbufUtils {
 		Pixbuf scaled = new Pixbuf (Colorspace.Rgb, false, 8, width, height);
 		scaled.Fill (0x000000); 
 
-		System.Console.WriteLine ("pos= {0}", pos.ToString ());
+		//System.Console.WriteLine ("pos= {0}", pos.ToString ());
 
 		orig.Composite (scaled, pos.X, pos.Y, 
 				pos.Width, pos.Height,
@@ -535,7 +535,7 @@ class PixbufUtils {
 		return orientation;
 	}
 
-	[DllImport("gnomeui-2")]
+	[DllImport("libgnomeui-2-0.dll")]
 	static extern IntPtr gnome_thumbnail_scale_down_pixbuf(IntPtr pixbuf, int dest_width, int dest_height);
 
 	public static Gdk.Pixbuf ScaleDown (Gdk.Pixbuf src, int width, int height)
